@@ -1,5 +1,7 @@
-from hypothesis import given, strategies as st
+import math
 
+from pytest import approx
+from hypothesis import given, strategies as st
 from hexagonal import Direction, Vec
 
 from . import veci
@@ -30,8 +32,6 @@ def test_abs(n):
     assert all([abs(d.value * n) == abs(n) for d in Direction])
 
 
-@given(veci(), veci())
-def test_cartesian_addition(u, v):
-    assert (u + v).cartesian() == tuple(
-        u.cartesian()[i] + v.cartesian()[i] for i in range(2)
-    )
+@given(veci())
+def test_round_ints(v):
+    assert v.round() == v
